/*
 * Copyright 2013-2016 microG Project Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.microg.nlp.api;

import android.content.Context;

public class AbstractBackendHelper {
    protected final Context context;
    protected State state = State.DISABLED;
    protected boolean currentDataUsed = true;

    public AbstractBackendHelper(Context context) {
        if (context == null)
            throw new IllegalArgumentException("context must not be null");
        this.context = context;
    }

    /**
     * Call this in {@link org.microg.nlp.api.LocationBackendService#onOpen()}.
     */
    public synchronized void onOpen() {
        if (state == State.WAITING || state == State.SCANNING)
            throw new IllegalStateException("Do not call onOpen if not closed before");
        currentDataUsed = true;
        state = State.WAITING;
    }

    /**
     * Call this in {@link org.microg.nlp.api.LocationBackendService#onClose()}.
     */
    public synchronized void onClose() {
        if (state == State.DISABLED || state == State.DISABLING)
            throw new IllegalStateException("Do not call onClose if not opened before");
        if (state == State.WAITING) {
            state = State.DISABLED;
        } else {
            state = State.DISABLING;
        }
    }

    /**
     * Call this in {@link org.microg.nlp.api.LocationBackendService#update()}.
     */
    public synchronized void onUpdate() {
    }

    public String[] getRequiredPermissions() {
        return new String[0];
    }

    protected enum State {DISABLED, WAITING, SCANNING, DISABLING}
}
