/*
 * Copyright 2013-2016 microG Project Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.microg.nlp.api;

import android.app.Service;
import android.content.Intent;
import android.os.IBinder;

public abstract class AbstractBackendService extends Service {

    @Override
    public IBinder onBind(Intent intent) {
        return getBackend();
    }

    /**
     * Called after a connection was setup
     */
    protected void onOpen() {

    }

    /**
     * Called before connection closure
     */
    protected void onClose() {

    }

    protected Intent getInitIntent() {
        return null;
    }

    protected Intent getSettingsIntent() {
        return null;
    }

    protected Intent getAboutIntent() {
        return null;
    }

    @Override
    public boolean onUnbind(Intent intent) {
        disconnect();
        return super.onUnbind(intent);
    }

    public abstract void disconnect();

    protected abstract IBinder getBackend();

    protected String getServiceApiVersion() {
        return VersionUtil.getServiceApiVersion(this);
    }

    protected String getSelfApiVersion() {
        return VersionUtil.getSelfApiVersion(this);
    }
}
